import click

from ..models import PagesCreator, PageCreator
from ..application import page_dir
from ..manager import cli

# TODO currently file is not used


@cli.command()
@click.option('--batch', is_flag=True, help='For making more than one new page')
@click.option('--pagetype', prompt='Page type to be created', type=click.Choice(['book', 'news', 'single']))
def newpage(batch, pagetype):
    """Creates a new page, prompting you for information"""
    path = page_dir(pagetype)

    if batch:
        pamount = click.prompt('Amount of new pages to make', type=int)

        lname = click.prompt('The title of the Book', default=None)
        sname = click.prompt('The shortname of your book (used for filenames)', default='')
        ptype = pagetype

        data = {
            "longname": lname,
            "shortname": sname,
            "pagetype": ptype,
            "path": path,
            "page_amount": pamount
        }

        thing = PagesCreator(**data)
        thing.write_page()

    else:
        lname = click.prompt('The title of the Book', default='')
        sname = click.prompt('The shortname of your book (used for filenames)', default='')
        ptype = pagetype
        ptitle = click.prompt('The title of the page', default=None)
        pnumber = click.prompt('The number of the page', type=int, default=None)
        chptr = click.prompt('The chapter number', type=int, default=None)
        img = click.prompt('The name of the image file of your comic page', default=sname+'_'+str(pnumber)+'.png')
        menu = click.prompt('True or False if you want to show up in main menu', type=bool, default=False)

        data = {
            "longname": lname,
            "shortname": sname,
            "pagetype": ptype,
            "pagetitle": ptitle,
            "pagenumber": pnumber,
            "chapter": chptr,
            "image": img,
            "menu": menu,
            "path": path
        }

        thing = PageCreator(**data)
        click.echo(thing.dump())



import os
import shutil

from flask import config
from . import default_settings

APP_ROOT = os.path.dirname(os.path.abspath(__file__))

# Flask instance folder, currently folder named 3color-Press in user's home folder
instfolder = os.path.join(os.path.expanduser("~"), '3color-Press')

examplecfg = os.path.join(instfolder, 'example.settings.cfg')

THEME_DIR = os.path.join(instfolder, 'themes')


def cfg_check(file):
    if os.path.exists(file):
        return True
    elif os.path.exists(examplecfg):
        shutil.copyfile(examplecfg, file)
        return True
    else:
        return False


def make_usr_cfg():
    if os.path.exists(instfolder):

        cfgfile = os.path.join(instfolder, 'settings.cfg')
        cfgcheck = cfg_check(cfgfile)

        # config using subclass of flask Config
        usr_cfg = config.Config(instfolder)
        usr_cfg.from_object(default_settings)

        if cfgcheck is True:
            usr_cfg.from_pyfile(cfgfile)

        # configure some path based values
        usr_cfg['TEMPLATES'] = os.path.join(THEME_DIR, usr_cfg['ACTIVE_THEME'], 'templates')
        usr_cfg['STATIC'] = os.path.join(THEME_DIR, usr_cfg['ACTIVE_THEME'], 'static')
        usr_cfg['FLATPAGES_ROOT'] = os.path.join(instfolder, 'content')
        usr_cfg['FREEZER_DESTINATION'] = os.path.join(instfolder, usr_cfg['BUILD_DIR'])

        # check to see if there is a theme folder with same name as active theme config
        if os.path.exists(os.path.join(THEME_DIR, usr_cfg['ACTIVE_THEME'])):
            usr_cfg['IMAGE_DIR'] = os.path.join(instfolder, 'images')
        else:
            usr_cfg['TEMPLATES'] = 'templates'
            usr_cfg['STATIC'] = 'static'

        return usr_cfg

    else:
        usr_cfg = config.Config(APP_ROOT)
        usr_cfg.from_object(default_settings)

        usr_cfg['TEMPLATES'] = 'templates'
        usr_cfg['STATIC'] = 'static'

        return usr_cfg



import click
import subprocess

from datetime import date

from .application import create_site, instfolder
from .tools import publish, misc
from .models import PagesCreator, PageCreator
from .site import coolviews

up = click.UNPROCESSED


@click.group()
def cli():
    """ 3color Press command line tool

    This provides command line tools to manage your 3color site.
    Simply pass a command after 3color to get something done!
    The project folder is the 3color-Press folder in your home directory.

    Commands available:

    \b
    build      Builds your website as static html to your build folder.
               The default build folder is 'build' in your project folder

    \b
    compress   Archives your build directory into a tar.gz file.
               Does the same as if your PUB_METHOD is local

    \b
    publish    Pushes your website to your remote server. It will use configured
               PUB_METHOD by default unless you supply --pubmethod option.
               Using --pubmethod will override your default method and must be one
               of these options: sftp, rsync, local, or git.
               \b
                 example: 3color publish --pubmethod rysnc

    \b
    all        Builds and then publishes your website.
               This is the same as running '3color build' and then '3color publish'

    \b
    open       Opens the project folder in your file browser

    \b
    atom       If you have the Atom Editor installed,
               this will call on atom to open your project folder in atom

    \b
    newpage    Creates a new page (.md file) based on your inputs.
               You can pass the option --batch in order to created a batch of pages
               with auto page numbering and file naming.
                \b
                  example: 3color newpage --batch
    \b
    run        Runs your website locally on port 5000 and opens http://localhost:5000
               in your default web browser. Use this command in order to see
               what your website will look like before you build it. Useful for
               Theme building. press contrl+c to halt the live server.

    """
    pass


@cli.command(name='all')
def build_push():
    """Builds and then publishes your website."""
    click.echo('building to build folder')
    app = create_site()
    coolviews.chill()
    click.echo('publishing with default pub method')
    publish.publish


@cli.command()
def build():
    """Builds website into static files"""
    click.echo('building')
    app = create_site()
    coolviews.chill()


@cli.command()
def compress():
    """Compress build folder into a tar.gz file"""
    click.echo('compressing')
    execute(publish.archive)


@cli.command(name='publish')
@click.option('--pubmethod', type=click.Choice(['sftp', 'rsync', 'local', 'git' ]))
def push_site(pubmethod):
    """Publish site to remote server"""
    click.echo('publishing')
    if pubmethod:
        publish.publish(pubmethod)
    else:
        publish.publish()


# FIXME launches browser windows
@cli.command()
def run():
    """Run website locally in debug mode"""
    click.launch('http://localhost:5000/')
    app = create_site()
    app.run()


@cli.command(name='open')
def open_file():
    """Open project folder"""
    click.launch(instfolder)


@cli.command()
@click.option('--batch', is_flag=True, help='For making more than one new page')
@click.option('--pagetype', prompt='Page type to be created',
              type=click.Choice(['book', 'news', 'single']), default='book')
# TODO: Create pagetype specific forms
def newpage(batch, pagetype):
    """Create a new page"""
    path = misc.page_dir(pagetype)

    if batch:
        pamount = click.prompt('Amount of new pages to make', type=int)

        lname = click.prompt('The title of the Book', default='', type=up)
        sname = click.prompt('The shortname of your book (used for filenames)',
                             default='', type=up)
        ptype = pagetype

        data = dict(
                longname=lname,
                shortname=sname,
                pagetype=ptype,
                path=path,
                page_amount=pamount
        )

        thing = PagesCreator(**data)
        thing.write_page()

    else:
        lname = click.prompt('The title of the Book', default='', type=up)
        sname = click.prompt('The shortname of your book (used for filenames)',
                             default='', type=up)
        ptype = pagetype
        ptitle = click.prompt('The title of the page',
                              default='{:%Y-%m-%d}'.format(date.today()))
        pnumber = click.prompt('The number of the page', type=int)
        chptr = click.prompt('The chapter number', type=int)
        img = click.prompt('The name of the image file of your comic page',
                           default=sname+'_'+str(pnumber)+'.png', type=up)
        menu = click.prompt('True or False for link in main menu',
                            type=bool, default=False)

        data = {
            "longname": lname,
            "shortname": sname,
            "pagetype": ptype,
            "pagetitle": ptitle,
            "pagenumber": pnumber,
            "chapter": chptr,
            "image": img,
            "menu": menu,
            "path": path
        }

        thing = PageCreator(**data)
        thing.write_page()


@cli.command()
def atom():
    """ Open project folder with atom editor"""
    try:
        if misc.system == 'Windows':
            subprocess.check_call(["atom", instfolder], shell=True)
        else:
            subprocess.check_call(["atom", instfolder])

    except OSError as e:
        print(os.strerror(e))
        print("The atom editor command line tool not installed")


# @cli.command(name='setup')
# def make_instance():
#     """Create your Project folder and copy over default config file"""
#     misc.make_home()



import os

from ..configs import config

from flask import abort, current_app, Blueprint, render_template, send_from_directory
from flask_flatpages import FlatPages
from flask_frozen import Freezer

freezer = Freezer()
pages = FlatPages()
cfg = config.make_usr_cfg()

site = Blueprint('site', __name__,
                 url_prefix='',
                 template_folder=cfg['TEMPLATES'],
                 static_folder=cfg['STATIC'],
                 static_url_path='/static/site'
                 )


@site.context_processor
def page_types():
    # injects variables for book pages and menu pages, menu pages are used to build main menu links
    menu_pages = (p for p in pages if (p['menu']))
    book_page = (p for p in pages if 'book' == p['page_type'])
    news_page = (p for p in pages if 'news' == p['page_type'])  # FIXME: uses same name as route function below
    thumb_nail = latest_comic(book_page, current_app.config['THUMB_STORY'], 1)
    book_list = (p['page_type'] for p in pages)  # FIXME: uses same name as book_list function below
    return {
        "book_page": book_page,
        "menu_pages": menu_pages,
        "news_page": news_page,
        "thumb_nail": thumb_nail,
        "book_list": book_list,
        "pages": pages
    }


def total_pages(pages, book):
    # takes a count of pages in the book and returns sum of pages, used for page navigation
    t_pages = (1 for p in pages if p.meta['book'] == book)
    t_pages = sum(t_pages)
    return t_pages


def latest_comic(pages, book, limit=None):
    # for sorting published pages that are books in the main story by latest
    l_comic = (p for p in pages if ((p['page_type'] == 'book') and p['book']['title'] == book))
    l_comic = sorted(l_comic, reverse=True, key=lambda p: p.meta['published'])
    return l_comic[:limit]


def page_feed(pages, limit=None):
    # for sorting published pages that are books by latest
    l_comic = (p for p in pages if p['page_type'] == 'book')
    l_comic = sorted(l_comic, reverse=True, key=lambda p: p.meta['published'])
    return l_comic[:limit]


def book_list():
    # returns a list of the book titles in book type
    first_page = (p for p in pages if p['book']['chapter'] == 1 and p['book']['page_number'] == 1)
    book_titles = [p['book']['title'] for p in first_page]
    return book_titles


@site.route('/images/<name>')
# static image file delivery
def images(name):
    path = current_app.config['IMAGE_DIR']
    if '..' in name or name.startswith('/'):
        abort(404)
    else:
        return send_from_directory(path, name)


@freezer.register_generator
# makes sure images in the instance/images folder get built into site
def images_url_generator():
    path = os.listdir(current_app.config['IMAGE_DIR'])
    for f in path:
        yield '/images/'+f


@site.route('/')
def index():
    # take 1 most recent page of published comics
    front_page = latest_comic(pages, current_app.config['MAIN_STORY'], 1)
    return render_template('home.html', front_page=front_page)


@site.route('/books/')
def books():
    # finds and lists pages that are chapter: 1 and page_number: 1 in yaml header
    first_page = (p for p in pages if p['book']['chapter'] == 1 and p['book']['page_number'] == 1)
    return render_template('books.html', first_page=first_page)


@site.route('/news/')
def news():
    # renders news template
    return render_template('news.html')

# @site.route('/atom.xml')
# atom feed, only works with a patch to werkzeug/contrip/atom.py file will look into more
# https://github.com/mitsuhiko/werkzeug/issues/695
# def atom_feed():
#     feed = AtomFeed('Feed for '+current_app.config['SITE_NAME'],
#                     feed_url=current_app.config['DOMAIN']+url_for('.atom_feed'),
#                     url=current_app.config['DOMAIN'])
#     # comic_feed = (p for p in pages if p.meta['page_type'] != 'single_page')
#     comic_feed = page_feed(pages, 10)
#     for p in comic_feed:
#         feed.add(p.meta['title'],
#                 content_type='html',
#                 url=current_app.config['DOMAIN']+p.path+'.html',
#                 updated=p.meta['published'],
#                 summary=p.body)
#     return feed.get_response()


@site.route('/<name>.html')
def single_page(name):
    # route for custom single pages, usually text pages such as about me or f.a.q's
    path = '{}/{}'.format(current_app.config['PAGE_DIR'], name)
    page = pages.get_or_404(path)
    return render_template('page.html', page=page)


@site.route('/news/<name>.html')
def news_page(name):
    # route for single pages, usually text pages
    path = '{}/{}'.format(current_app.config['NEWS_DIR'], name)
    page = pages.get_or_404(path)
    return render_template('page.html', page=page)


@site.route('/<book>/c<int:chapter>/p<int:number>/<name>.html')
def comic_page(book, chapter, number, name):
    # variables after 'p' are used to create pagination links within the book stories.
    # these are only passed into the page.html template and work only on 'comic_page' urls
    path = '{}/{}'.format(current_app.config['BOOK_DIR'], name)
    p = pages.get_or_404(path)
    t_pages = total_pages(pages, p['book']['title'])
    minus = p['book']['page_number'] - 1
    plus = p['book']['page_number'] + 1
    current_book = p['book']['title']
    current_chapter = p.meta['book']['chapter']
    first_page = (p for p in pages if p['book']['page_number'] == 1 and p['book']['title'] == current_book)
    last_page = (p for p in pages if p['book']['page_number'] == t_pages)
    previous_page = (p for p in pages if p['book']['page_number'] == minus)
    next_page = (p for p in pages if p['book']['page_number'] == plus)
    return render_template(
        'comic.html',
        current_book=current_book,
        current_chapter=current_chapter,
        p=p,
        previous_page=previous_page,
        next_page=next_page,
        t_pages=t_pages,
        last_page=last_page,
        first_page=first_page
    )


def chill():
    # function to build the site into static files
    freezer.freeze()



import os
import subprocess

from ..application import create_site
from ..configs import config

# TODO: make fabric optional
from fabric.api import *
from fabric.api import execute
from fabric.contrib.project import rsync_project
from fabric.contrib.files import exists

from shutil import make_archive

instfolder = config.instfolder

cfg = config.make_usr_cfg()

# configure user and hostname for remote server
env.user = cfg['USER_NAME']
env.hosts = cfg['REMOTE_SERVER']
pub_method = cfg['PUB_METHOD']
build_dir = cfg['FREEZER_DESTINATION']


def archive():
    """
    Makes a local tar.gz file
    """
    make_archive(os.path.join(instfolder, '3colorSite'), 'gztar', build_dir)


def rsync():
    """
    Uses a wrapper to call rsync to deploy your site with the rsync tool
    this has the delete option which will delete any remote files that are
    not in your local build folder
    """
    local = os.path.join(instfolder, build_dir+'/')
    remote = '3colorsite/'
    rsync_project(remote, local, delete=True)


# TODO test functionality
def git_deploy():
    """
    simply changes the directory to your build directory and calls
    git commits to add all files, commit all changes with commit message updated
    and then push your commit, then change back to your project directory
    """
    project = os.getcwd()
    local = os.path.join(instfolder, build_dir)
    os.chdir(local)
    subprocess.call(['git', 'add', '-A'])
    subprocess.call(['git', 'commit', '-a', '-m', 'updated'])
    subprocess.call(['git', 'push'])
    os.chdir(project)


# TODO: make nicer, add non-fabric plain FTP support
def sftp():
    """
    archives then uploads site via fabric sftp and then unarchives on server.
    The remote folder for your site will be 3colorsite and contents will be deleted
    if the directory exists remotely therefore ensuring to remove changes before the upload
    """
    make_archive(os.path.join(instfolder, '3colorSite'), 'gztar', build_dir)
    tarfile = os.path.join(instfolder, '3colorSite.tar.gz')

    if exists('~/3colorSite'):
        run('rm -rf ~/3colorSite/*')
        put(tarfile, '~/3colorSite/3colorSite.tar.gz')
        with cd('~/3colorSite/'):
            run('tar xzf 3colorSite.tar.gz')
            run('rm -rf 3colorSite.tar.gz')
    else:
        run('mkdir ~/3colorSite')
        put(tarfile, '~/3colorSite/3colorSite.tar.gz')
        with cd('~/3colorSite/'):
            run('tar xzf 3colorSite.tar.gz')
            run('rm -rf 3colorSite.tar.gz')

    os.remove(tarfile)


def publish(pubmethod=pub_method):
    """Main function to pubish site"""
    if pubmethod == 'sftp':
        execute(sftp)

    elif pubmethod == 'rsync':
        execute(rsync)

    elif pubmethod == 'git':
        git_deploy()

    elif pubmethod == 'local':
        archive()

    else:
        print("You did not configure your publish method")



import os
import subprocess
import shutil
import platform

from ..configs import config

instfolder = config.instfolder

system = platform.system()


def page_dir(dirname):
    """used in command line tools to determine path for content type"""
    ptype_dir = os.path.join(instfolder, 'content', dirname)
    return ptype_dir


def open_browser():
    """
    Try's to open system's file browser.

    Currently the command line tool uses click.launch but this
    may be used for future admin interface
    """
    if system == 'Windows':
        os.startfile(instfolder['open'])
    elif system == 'Darwin':
        subprocess.call(["open", instfolder])
    else:
        try:
            subprocess.call(['xdg-open', instfolder])
        except OSError:
            print("Operating system doesn't have lazy file browser opener")


def make_home(root_path):
    """
    This function looks for the user's 3color-Press folder (instance folder)
    and creates one if it doesn't exist. Currently not in use
     """
    inst_dir_list = ['content', 'images', 'themes']
    content_dir_list = ['book', 'news', 'single']

    if os.path.exists(instfolder):
        print("3color-Press folder already exists")

    else:
        os.mkdir(instfolder)
        shutil.copyfile(os.path.join(root_path, 'configs', 'example.settings.cfg'),
                        os.path.join(instfolder, 'settings.cfg'))

        for folder in inst_dir_list:
            os.mkdir(os.path.join(instfolder, folder))

        for folder in content_dir_list:
            os.mkdir(os.path.join(instfolder, 'content', folder))



import os
import yaml

from . import __version__
from datetime import date


class PageHeader(object):
    """

        Class that handles page header data. The page header is a yaml header
    at the beginnning of the markdown file that will be turned into a page.

    """

    def __init__(self, **kwargs):

        # self.longname = kwargs['longname']
        # self.pagetype = kwargs['pagetype']
        # self.pageamount = kwargs['pageamount']
        # self.pagetitle = kwargs['pagetitle']
        # self.pagenumber = kwargs['pagenumber']
        # self.published = kwargs['pub']
        # self.modified = kwargs['mod']
        # self.image = kwargs['image']
        # self.menu = kwargs['menu']
        self.__dict__.update(kwargs)

    @property
    def header(self):
        """
        Make a dict from kwargs
        """
        return {
            "title": self.pagetitle,
            "published": self.pub,
            "modified": self.mod,
            "page_type": self.pagetype,
            "book": {
                'title': self.longname,
                'chapter': self.chapter,
                'page_number': self.pagenumber,
                'image': self.image
            },
            "menu": self.menu,
            "version": __version__
        }

    def write_page(self):
        """ Writes the dict from header funtion into a file. This is our page metadata information"""
        name = os.path.join(self.path, self.shortname+'_'+str(self.pagenumber)+'.md')
        with open(name, "ab") as f:
            yaml.dump(self.header, f)

    def dump(self):
        """test function"""
        name = os.path.join(self.path, self.shortname+'_'+str(self.pagenumber)+'.md')
        info = yaml.safe_dump(self.header)
        return name+'\n'+info


class PagesCreator(PageHeader):

    """Subclass of PageHeader for making batch yaml headers and markdown files"""

    def __init__(self, **kwargs):
        super(PagesCreator, self).__init__(**kwargs)
        self.index = 0
        self.pub = '{:%Y-%m-%d}'.format(date.today())
        self.mod = '{:%Y-%m-%d}'.format(date.today())

    def header(self, n):

        """
        Overrides PageHeader's header funtion to one needed for batch creation
        """

        return {
            "title": '',
            "published": self.pub,
            "modified": self.mod,
            "page_type": self.pagetype,
            "book": {'title': self.longname, 'chapter': '', 'page_number': n, 'image': ''},
            "menu": False,
            "version": __version__
        }

    def write_page(self):
        """ Writes the dict from header funtion into a file. This is our page metadata information"""

        for x in range(1, self.page_amount+1):
            name = os.path.join(self.path, self.shortname+'_'+str(self.index+x)+'.md')
            number = self.index+x
            with open(name, "ab") as f:
                yaml.safe_dump(self.header(number), f)


class PageCreator(PageHeader):

    def __init__(self, **kwargs):
        super(PageCreator, self).__init__(**kwargs)
        self.pub = '{:%Y-%m-%d}'.format(date.today())
        self.mod = '{:%Y-%m-%d}'.format(date.today())



DEBUG = True
FLATPAGES_AUTO_RELOAD = DEBUG
FLATPAGES_EXTENSION = '.md'
FLATPAGES_ROOT = 'content'
FREEZER_DESTINATION_IGNORE = ['.git*', '.gitignore', 'CNAME']
FEEZER_RELATIVE_URLS = True
SITE_NAME = '3color Press Site'
BUILD_DIR = 'build'
BOOK_DIR = 'book'
PAGE_DIR = 'single'
NEWS_DIR = 'news'
DOMAIN = ''
MAIN_STORY = ''
THUMB_STORY = ''
USER_NAME = ''
REMOTE_SERVER = ''
PUB_METHOD = 'local'
ACTIVE_THEME = 'default'



import os
import platform
import subprocess

from setuptools import setup, find_packages

#foldercreation
instfolder = os.path.join(os.path.expanduser("~"), '3color-Press')

folders = ['content','images','themes']
contfolders = ['book', 'news', 'single']

# TODO: add checks for
if os.path.exists(instfolder) is False:
    os.mkdir(instfolder)
    for folder in folders:
        os.mkdir(os.path.join(instfolder, folder))
    for folder in contfolders:
        os.mkdir(os.path.join(instfolder, 'content', folder))

with open('README.txt') as file:
    long_description = file.read()

if platform.system() == 'Windows':

    subprocess.call(
        ['easy_install', "http://www.voidspace.org.uk/downloads/pycrypto26/pycrypto-2.6.win-amd64-py2.7.exe"]
    )

setup(
    name='3color-Press',
    version='0.2.1',
    author='Martin Knobel',
    author_email='mknobel@noties.org',
    license='BSD',
    url='3color.noties.org',
    description='A Flask based static site generator for comics',
    long_description=long_description,
    packages=find_packages(),
    include_package_data=True,
    data_files=[
        (instfolder, ['threecolor/configs/example.settings.cfg']),
    ],
    install_requires=[
        'Click',
        'Flask > 0.8',
        'Flask-FlatPages',
        'Frozen-Flask',
        'Fabric'
    ],
    entry_points='''
        [console_scripts]
        3color=threecolor.manager:cli
        ''',

    classifiers=[
        'Environment :: Console',
        'Environment :: Web Environment',
        'Framework :: Flask',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: End Users/Desktop',
        'Development Status :: 3 - Alpha',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP :: Site Management',
    ]
)



import os

from flask import Flask
from .tools import misc
from .configs import config

# set application root path
APP_ROOT = os.path.dirname(os.path.abspath(__file__))

instfolder = config.instfolder
THEME_DIR = config.THEME_DIR


def create_site():
    """App factory to create website"""
    if os.path.exists(instfolder):

        app = Flask('threecolor', instance_path=instfolder, instance_relative_config=True)

        # configure flask app from default settings, then overide with settings.cfg
        app.config.from_object('threecolor.configs.default_settings')
        app.config.from_pyfile('settings.cfg')

        # configure paths and folders according to instance path
        app.config['FLATPAGES_ROOT'] = os.path.join(app.instance_path, 'content')
        app.config['IMAGE_DIR'] = os.path.join(app.instance_path, 'images')
        app.config['FREEZER_DESTINATION'] = os.path.join(app.instance_path, app.config['BUILD_DIR'])

        from .site.coolviews import site, pages, freezer
        app.register_blueprint(site)
        pages.init_app(app)
        freezer.init_app(app)

        return app

    else:
        # app = Flask('threecolor')
        #
        # # configure flask app from default settings, then overide with settings.cfg
        # app.config.from_object('threecolor.configs.default_settings')

        misc.make_home(APP_ROOT)

        return app


def create_admin():
    """Place holder for eventual admin site interface"""
    pass
